@@ -36,7 +36,7 @@ class LabExtDataTable {
     };
     this.isInitComplete = false;
 
-    this.tunnel.send_msg(JSON.stringify({"type": "handshake", "msg": "init_start"}));
+    this.tunnel.send_msg(JSON.stringify({"type": "status", "msg": "init_start"}));
   }
 
   render() {
@@ -73,7 +73,12 @@ class LabExtDataTable {
       },
       initComplete: () => {
         this.isInitComplete = true;
-        this.tunnel.send_msg(JSON.stringify({"type": "handshake", "msg": "init_done"}));
+        this.tunnel.send_msg(JSON.stringify({"type": "status", "msg": "init_done"}));
+      },
+      drawCallback: () => {
+        if (this.isInitComplete) {
+          this.tunnel.send_msg(JSON.stringify({"type": "status", "msg": "redraw"}));
+        }
       },
       ...this.options
     });
